==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/es.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'es', {
	button: {
		title: 'Propiedades de Botón',
		text: 'Texto (Valor)',
		type: 'Tipo',
		typeBtn: 'Boton',
		typeSbm: 'Enviar',
		typeRst: 'Reestablecer'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propiedades de Casilla',
		radioTitle: 'Propiedades de Botón de Radio',
		value: 'Valor',
		selected: 'Seleccionado'
	},
	form: {
		title: 'Propiedades de Formulario',
		menu: 'Propiedades de Formulario',
		action: 'Acción',
		method: 'Método',
		encoding: 'Codificación'
	},
	hidden: {
		title: 'Propiedades de Campo Oculto',
		name: 'Nombre',
		value: 'Valor'
	},
	select: {
		title: 'Propiedades de Campo de Selección',
		selectInfo: 'Información',
		opAvail: 'Opciones disponibles',
		value: 'Valor',
		size: 'Tamaño',
		lines: 'Lineas',
		chkMulti: 'Permitir múltiple selección',
		opText: 'Texto',
		opValue: 'Valor',
		btnAdd: 'Agregar',
		btnModify: 'Modificar',
		btnUp: 'Subir',
		btnDown: 'Bajar',
		btnSetValue: 'Establecer como predeterminado',
		btnDelete: 'Eliminar'
	},
	textarea: {
		title: 'Propiedades de Area de Texto',
		cols: 'Columnas',
		rows: 'Filas'
	},
	textfield: {
		title: 'Propiedades de Campo de Texto',
		name: 'Nombre',
		value: 'Valor',
		charWidth: 'Caracteres de ancho',
		maxChars: 'Máximo caracteres',
		type: 'Tipo',
		typeText: 'Texto',
		typePass: 'Contraseña',
		typeEmail: 'Correo electrónico',
		typeSearch: 'Buscar',
		typeTel: 'Número de teléfono',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/es.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'es', {
	button: {
		title: 'Propiedades de Botón',
		text: 'Texto (Valor)',
		type: 'Tipo',
		typeBtn: 'Boton',
		typeSbm: 'Enviar',
		typeRst: 'Reestablecer'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propiedades de Casilla',
		radioTitle: 'Propiedades de Botón de Radio',
		value: 'Valor',
		selected: 'Seleccionado',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Propiedades de Formulario',
		menu: 'Propiedades de Formulario',
		action: 'Acción',
		method: 'Método',
		encoding: 'Codificación'
	},
	hidden: {
		title: 'Propiedades de Campo Oculto',
		name: 'Nombre',
		value: 'Valor'
	},
	select: {
		title: 'Propiedades de Campo de Selección',
		selectInfo: 'Información',
		opAvail: 'Opciones disponibles',
		value: 'Valor',
		size: 'Tamaño',
		lines: 'Lineas',
		chkMulti: 'Permitir múltiple selección',
		required: 'Required', // MISSING
		opText: 'Texto',
		opValue: 'Valor',
		btnAdd: 'Agregar',
		btnModify: 'Modificar',
		btnUp: 'Subir',
		btnDown: 'Bajar',
		btnSetValue: 'Establecer como predeterminado',
		btnDelete: 'Eliminar'
	},
	textarea: {
		title: 'Propiedades de Area de Texto',
		cols: 'Columnas',
		rows: 'Filas'
	},
	textfield: {
		title: 'Propiedades de Campo de Texto',
		name: 'Nombre',
		value: 'Valor',
		charWidth: 'Caracteres de ancho',
		maxChars: 'Máximo caracteres',
		required: 'Required', // MISSING
		type: 'Tipo',
		typeText: 'Texto',
		typePass: 'Contraseña',
		typeEmail: 'Correo electrónico',
		typeSearch: 'Buscar',
		typeTel: 'Número de teléfono',
		typeUrl: 'URL'
	}
} );
